Detector Class
==============

.. autoclass:: bssunfold.Detector
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__, __str__, __repr__
   
   .. automethod:: __init__
   .. automethod:: unfold_cvxpy
   .. automethod:: unfold_landweber
   .. autoattribute:: n_detectors
   .. autoattribute:: n_energy_bins